@@ -27,7 +27,7 @@ def run_cohesion(df, docs_percent, topics_percent, del_tmp):
     create_future_dirs()
     topics = create_topic_names_using_tf_idf(docs, labels)
     topics_names = extract_topics_labels(topics)
-    detailed_topics_print(topics_names)
+    # detailed_topics_print(topics_names)
     cohesion_score = calculate_cohesion_score(ground_truth_docs_list=docs,
                                               division_labels=labels, topics_names=topics_names, docs_percent=docs_percent, topics_percent=topics_percent)
     topics_values = [" ".join(topic_words) for topic_words in topics_names]
